==> relations-0.0.1.tar.gz: lib/bloc/stage_bloc.dart <==
import 'dart:async';
import 'package:bloc/bloc.dart';
import '../models/stage_session_data.dart';
import '../models/stage_theme.dart';
import '../view/stage_items/edge.dart';
import '../view/stage_items/wrapper_box.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/rendering.dart';
import './bloc.dart';
import 'package:rxdart/rxdart.dart';

class StageBloc extends Bloc<StageEvent, StageSessionData> {
  /// it is neccessary to provide static access to the bounds
  static Rect stageBounds;
  final Size stageSize;

  final StageTheme theme;
  
  /// Receiving the whole transform matrix, 
  /// but all we need is to raise notification when only the scaling changes.
  PublishSubject<Matrix4> $stageTransformState;
  Observable<Matrix4> get stageTransformNotifier => $stageTransformState.stream;
  void changeScale(Matrix4 matrix) => $stageTransformState.add(matrix);

  StageBloc({@required this.stageSize, @required this.theme}) : super() {
    stageBounds = currentState.bounds;

    $stageTransformState = PublishSubject<Matrix4>();
    /// save it, because we want to provide this value for rebuilt items (Edge, WrapperBox)
    $stageTransformState.listen((Matrix4 data) => this.currentState.stageScale = data.getMaxScaleOnAxis());
  }
  
  Offset get stageCenter => stageBounds.center;

  @override
  StageSessionData get initialState => StageSessionData( 
    bounds:  Rect.fromLTWH(0, 0, this.stageSize.width, this.stageSize.height),
    connectionEnabled: false
  );

  @override
  Stream<StageSessionData> mapEventToState(
    StageEvent event,
  ) async* {
    if (event is StageUpdateEvent) {
      // newstate
      final allround = currentState.copy();
      yield allround;
    }
  }

  void _updateState() {
    this.dispatch(StageUpdateEvent());
  }

  void setConnectionMode(bool value) {
    currentState.connectionEnabled = value;
    _updateState();
  }

  void toggleConnectionMode() {
    currentState.connectionEnabled = !currentState.connectionEnabled;
    _updateState();
  }

  void setSelectedBox(WrapperBoxState box) {
    currentState.selectedEntity?.unselect();
    currentState.selectedEntity = box;
    currentState.selectedBox = box;
    currentState.selectedEntity.select();
  }

  void setTappedPos(Offset pos) {
    currentState.tappedPos = pos;
  }

  void setSelectedEdge(EdgeState edge) {
    currentState.selectedEntity?.unselect();
    currentState.selectedEntity = edge;
    currentState.selectedEdge = edge;
    currentState.selectedEntity.select();
  }

  void unselect() {
    currentState.selectedEntity?.unselect();
    currentState.selectedBox = null;
    currentState.selectedEdge = null;
    currentState.selectedEntity = null;
  }

  @override
  void dispose() {
    super.dispose();
    $stageTransformState.close();
  }
}

==> relations-0.0.3.tar.gz: lib/bloc/stage_bloc.dart <==
import 'dart:async';
import 'package:bloc/bloc.dart';
import '../models/stage_session_data.dart';
import '../models/stage_theme.dart';
import '../view/stage_items/edge.dart';
import '../view/stage_items/wrapper_box.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/rendering.dart';
import './bloc.dart';
import 'package:rxdart/rxdart.dart';

class StageBloc extends Bloc<StageEvent, StageSessionData> {
  /// it is neccessary to provide static access to the bounds
  static Rect stageBounds;
  final Size stageSize;

  final StageTheme theme;

  /// Receiving the whole transform matrix,
  /// but all we need is to raise notification when only the scaling changes.
  PublishSubject<Matrix4> $stageTransformState;
  Observable<Matrix4> get stageTransformNotifier => $stageTransformState.stream;
  void changeScale(Matrix4 matrix) => $stageTransformState.add(matrix);

  StageBloc({@required this.stageSize, @required this.theme}) : super() {
    stageBounds = currentState.bounds;

    $stageTransformState = PublishSubject<Matrix4>();

    /// save it, because we want to provide this value for rebuilt items (Edge, WrapperBox)
    $stageTransformState.listen((Matrix4 data) =>
        this.currentState.stageScale = data.getMaxScaleOnAxis());
  }

  Offset get stageCenter => stageBounds.center;

  @override
  StageSessionData get initialState => StageSessionData(
      bounds: Rect.fromLTWH(0, 0, this.stageSize.width, this.stageSize.height),
      connectionEnabled: false);

  @override
  Stream<StageSessionData> mapEventToState(
    StageEvent event,
  ) async* {
    if (event is StageUpdateEvent) {
      // newstate
      final allround = currentState.copy();
      yield allround;
    }
  }

  void _updateState() {
    this.dispatch(StageUpdateEvent());
  }

  void setConnectionMode(bool value) {
    currentState.connectionEnabled = value;
    _updateState();
  }

  void toggleConnectionMode() {
    currentState.connectionEnabled = !currentState.connectionEnabled;
    _updateState();
  }

  void setSelectedBox(WrapperBoxState box) {
    currentState.selectedEntity?.unselect();
    currentState.selectedEntity = box;
    currentState.selectedBox = box;
    currentState.selectedEntity.select();
  }

  void setTappedPos(Offset pos) {
    currentState.tappedPos = pos;
  }

  void setSelectedEdge(EdgeState edge) {
    currentState.selectedEntity?.unselect();
    currentState.selectedEntity = edge;
    currentState.selectedEdge = edge;
    currentState.selectedEntity.select();
  }

  void unselect() {
    currentState.selectedEntity?.unselect();
    currentState.selectedBox = null;
    currentState.selectedEdge = null;
    currentState.selectedEntity = null;
  }

  @override
  void dispose() {
    super.dispose();
    $stageTransformState.close();
  }
}
